==> bigloo2.0a.tar.gz: bigloo2.0a/comptime/Foreign/access.scm <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.9/Foreign/access.scm       */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Jun  5 11:16:50 1996                          */
;*    Last change :  Wed Jul 17 15:36:03 1996 (serrano)                */
;*    -------------------------------------------------------------    */
;*    We make the ctype accessors                                      */
;*    -------------------------------------------------------------    */
;*    This function simply defines and exports the generic             */
;*    accessors builder function. It is imported by all the specific   */
;*    accessors builders.                                              */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module foreign_access
   
   (import type_type
	   foreign_calias
	   foreign_cenum
	   foreign_cfunction
	   foreign_cpointer
	   foreign_cstruct)
   
   (export (generic make-ctype-accesses! ::type ::type)))

;*---------------------------------------------------------------------*/
;*    make-ctype-accesses! ...                                         */
;*---------------------------------------------------------------------*/
(define-generic (make-ctype-accesses! what::type who::type)
   '())

==> bigloo3.1a.tar.gz: bigloo3.1a/comptime/Foreign/access.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Foreign/access.scm          */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Jun  5 11:16:50 1996                          */
;*    Last change :  Mon May 15 07:47:43 2000 (serrano)                */
;*    Copyright   :  1996-2000 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    We make the ctype accessors                                      */
;*    -------------------------------------------------------------    */
;*    This function simply defines and exports the generic             */
;*    accessors builder function. It is imported by all the specific   */
;*    accessors builders.                                              */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module foreign_access
   
   (import type_type
	   foreign_calias
	   foreign_cenum
	   foreign_copaque
	   foreign_cfunction
	   foreign_cpointer
	   foreign_cstruct)
   
   (export (generic make-ctype-accesses! ::type ::type loc)))

;*---------------------------------------------------------------------*/
;*    make-ctype-accesses! ...                                         */
;*---------------------------------------------------------------------*/
(define-generic (make-ctype-accesses! what::type who::type loc)
   '())
